pub fn poll_blocking(config: ConfigParams)Expand description
Convenience: start the polling loop and block the current thread until it ends (infinite loop).
pub fn poll_blocking(config: ConfigParams)Convenience: start the polling loop and block the current thread until it ends (infinite loop).