Structs
- Config
Params - The struct contains all config params for running the task worker
Functions
- load_
config_ from_ env - Loads the configuration into a ConfigParams struct. The function may panic, but it should not happen because ConfigParams provides default values for all configured entries.